==> gatsby-source-datocms-4.0.2.tgz: package/src/hooks/sourceNodes/createTypes/item/fields/richText.js <==
const { pascalize } = require('humps');
const itemNodeId = require('../../utils/itemNodeId');

module.exports = ({
  parentItemType,
  field,
  schema,
  gqlItemTypeName,
  entitiesRepo,
  generateType,
}) => {
  const parentItemTypeName = gqlItemTypeName(parentItemType);

  const itemTypeIds =
    field.validators[
      field.fieldType === 'rich_text' ? 'richTextBlocks' : 'itemsItemType'
    ].itemTypes;

  if (itemTypeIds.length === 0) {
    return { type: 'String' };
  }

  if (itemTypeIds.length === 1) {
    const linkedItemType = entitiesRepo.findEntity('item_type', itemTypeIds[0]);

    return {
      type: `[${gqlItemTypeName(linkedItemType)}]`,
      resolveForSimpleField: (fieldValue, context, node) => {
        const ids = (fieldValue || []).map(id =>
          itemNodeId(
            id,
            node.forcedLocale || node.locale,
            entitiesRepo,
            generateType,
          ),
        );
        return context.nodeModel
          .getNodesByIds({ ids })
          .map(n => ({ ...n, forcedLocale: node.locale }));
      },
    };
  }

  const unionType = `DatoCmsUnionFor${parentItemTypeName}${pascalize(
    field.apiKey,
  )}`;

  return {
    additionalTypesToCreate: [
      schema.buildUnionType({
        name: unionType,
        types: itemTypeIds.map(id =>
          gqlItemTypeName(entitiesRepo.findEntity('item_type', id)),
        ),
      }),
    ],
    type: `[${unionType}]`,
    resolveForSimpleField: (fieldValue, context, node) => {
      const ids = (fieldValue || []).map(id =>
        itemNodeId(
          id,
          node.forcedLocale || node.locale,
          entitiesRepo,
          generateType,
        ),
      );
      return context.nodeModel
        .getNodesByIds({ ids })
        .map(n => ({ ...n, forcedLocale: node.locale }));
    },
  };
};

==> gatsby-source-datocms-4.0.5.tgz: package/src/hooks/sourceNodes/createTypes/item/fields/richText.js <==
const { pascalize } = require('humps');
const itemNodeId = require('../../utils/itemNodeId');

module.exports = ({
  parentItemType,
  field,
  schema,
  gqlItemTypeName,
  entitiesRepo,
  generateType,
}) => {
  const parentItemTypeName = gqlItemTypeName(parentItemType);

  const itemTypeIds =
    field.validators[
      field.fieldType === 'rich_text' ? 'richTextBlocks' : 'itemsItemType'
    ].itemTypes;

  if (itemTypeIds.length === 0) {
    return { type: 'String' };
  }

  if (itemTypeIds.length === 1) {
    const linkedItemType = entitiesRepo.findEntity('item_type', itemTypeIds[0]);

    return {
      type: `[${gqlItemTypeName(linkedItemType)}]`,
      resolveForSimpleField: (fieldValue, context, node) => {
        const ids = (fieldValue || []).map(id =>
          itemNodeId(
            id,
            node.forcedLocale || node.locale,
            entitiesRepo,
            generateType,
          ),
        );
        return context.nodeModel
          .getNodesByIds({ ids })
          .map(n => ({ ...n, forcedLocale: node.forcedLocale || node.locale }));
      },
    };
  }

  const unionType = `DatoCmsUnionFor${parentItemTypeName}${pascalize(
    field.apiKey,
  )}`;

  return {
    additionalTypesToCreate: [
      schema.buildUnionType({
        name: unionType,
        types: itemTypeIds.map(id =>
          gqlItemTypeName(entitiesRepo.findEntity('item_type', id)),
        ),
      }),
    ],
    type: `[${unionType}]`,
    resolveForSimpleField: (fieldValue, context, node) => {
      const ids = (fieldValue || []).map(id =>
        itemNodeId(
          id,
          node.forcedLocale || node.locale,
          entitiesRepo,
          generateType,
        ),
      );
      return context.nodeModel
        .getNodesByIds({ ids })
        .map(n => ({ ...n, forcedLocale: node.forcedLocale || node.locale }));
    },
  };
};
